==> bookkeeper-4.11.1-src.tar.gz: bookkeeper-4.11.1/bookkeeper-server/src/test/java/org/apache/bookkeeper/test/LocalBookiesRegistryTest.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.bookkeeper.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.apache.bookkeeper.proto.BookieServer;
import org.apache.bookkeeper.proto.LocalBookiesRegistry;
import org.junit.Test;

/**
 * Test the correctness and the availability outside of its package of LocalBookiesRegistryTest.
 */
public class LocalBookiesRegistryTest extends BookKeeperClusterTestCase {

    public LocalBookiesRegistryTest() {
        super(3);
        baseConf.setDisableServerSocketBind(true);
        baseConf.setEnableLocalTransport(true);
    }

    @Test
    public void testAccessibleLocalBookiesRegistry() throws Exception {
        assertEquals(3, bs.size());
        for (BookieServer bk : bs) {
            assertTrue(LocalBookiesRegistry.isLocalBookie(bk.getLocalAddress()));
        }
    }
}

==> bookkeeper-4.13.0-src.tar.gz: bookkeeper-4.13.0/bookkeeper-server/src/test/java/org/apache/bookkeeper/test/LocalBookiesRegistryTest.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.bookkeeper.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.apache.bookkeeper.proto.BookieServer;
import org.apache.bookkeeper.proto.LocalBookiesRegistry;
import org.junit.Test;

/**
 * Test the correctness and the availability outside of its package of LocalBookiesRegistryTest.
 */
public class LocalBookiesRegistryTest extends BookKeeperClusterTestCase {

    public LocalBookiesRegistryTest() {
        super(1);
        baseConf.setDisableServerSocketBind(true);
        baseConf.setEnableLocalTransport(true);
    }

    @Test
    public void testAccessibleLocalBookiesRegistry() throws Exception {
        assertEquals(1, bs.size());
        for (BookieServer bk : bs) {
            assertTrue(LocalBookiesRegistry.isLocalBookie(bk.getBookieId()));
        }
    }
}
